<?php
/**
 * @package Rectangulum
 */

add_action( 'admin_init', 'rectangulum_theme_settings_init' );
add_action( 'admin_menu', 'rectangulum_add_settings_page' );

/*=SETUP----------------------------------------------------*/

function rectangulum_theme_settings_init(){
	register_setting( 'rectangulum_theme_settings', 'rectangulum_theme_settings', 'rectangulum_options_validate' );
}

function rectangulum_admin_enqueue_scripts( $hook_suffix ) {
	$template_directory_uri = get_template_directory_uri();

	wp_enqueue_style( 'rectangulum-theme-options', $template_directory_uri . '/theme-options/theme-options.css', false, '1.5' );
	wp_enqueue_script( 'rectangulum-theme-options', $template_directory_uri . '/theme-options/theme-options.js', array( 'jquery' ), '1.5' );

	wp_enqueue_script('media-upload');
	wp_enqueue_script('thickbox');
	wp_enqueue_style('thickbox');
}
add_action( 'admin_print_styles-appearance_page_setting', 'rectangulum_admin_enqueue_scripts' );

function rectangulum_add_settings_page() {
	global $rectangulum_admin_page;

	$rectangulum_admin_page = add_theme_page( __( 'Theme Options', 'rectangulum' ), __( 'Theme Options', 'rectangulum' ), 'manage_options', 'setting', 'rectangulum_theme_settings_page');

	// Contextual Help
	add_action( 'load-' . $rectangulum_admin_page, 'rectangulum_admin_contextual_help' );
}

function options_echo_scripts()
{
?>
<script type="text/javascript">
//<![CDATA[
jQuery(document).ready(function() {

// Media Uploader
window.formfield = '';

jQuery('.upload_image_button').live('click', function() {
	window.formfield = jQuery('.upload_field',jQuery(this).parent());
	tb_show('', 'media-upload.php?type=image&TB_iframe=true');
	return false;
});

window.original_send_to_editor = window.send_to_editor;
window.send_to_editor = function(html) {
	if (window.formfield) {
		imgurl = jQuery('img',html).attr('src');
		window.formfield.val(imgurl);
		tb_remove();
	}
	else {
		window.original_send_to_editor(html);
	}
	window.formfield = '';
	window.imagefield = false;
}

});
//]]> 
</script>
<?php
}
add_action('admin_head', 'options_echo_scripts');

/**
 * Options Page Build
 */
function rectangulum_theme_settings_page() {	
?>

<!--GO Page Options-->

<div class="wrap">

<?php
if ( isset ($_GET['settings-updated']) ) { ?>
<div id="message" class="updated fade -message"><p><?php _e('Options Saved','rectangulum'); ?></p></div>
<?php } ?>

<h2><?php $theme_name = wp_get_theme(); echo $theme_name ?><?php _e( ' Theme Options', 'rectangulum' ) ?></h2>

<form method="post" action="options.php">

<?php settings_fields( 'rectangulum_theme_settings' ); ?>
<?php $options = get_option( 'rectangulum_theme_settings' ); ?>

<table class="form-table">

<tr valign="top">
<th scope="row">
<?php _e( 'Avatar', 'rectangulum' ); ?>
</th>
<td>
<input id="rectangulum_theme_settings[file_avatar]" class="regular-text upload_field" type="text" size="36" name="rectangulum_theme_settings[file_avatar]" value="<?php echo esc_url($options['file_avatar']); ?>" />
<input class="upload_image_button button-secondary" type="button" value="Upload Image" />
<br />
<label class="description" for="rectangulum_theme_settings[file_avatar]"><?php _e( 'Upload or enter URL file the image instead of the Gravatar. Better square image larger than 120x120px','rectangulum'); ?></label>
</td>
</tr>

<tr valign="top">
<th scope="row"><?php _e( 'Disable Top bar', 'rectangulum' ); ?></th>
<td>
<input id="rectangulum_theme_settings[topbar_disable]" class="checkbox" type="checkbox" name="rectangulum_theme_settings[topbar_disable]" value="1" <?php checked( $options['topbar_disable'], 1 ); ?> />
<label class="description" for="rectangulum_theme_settings[topbar_disable]"><?php _e( 'Check the box if you want not to show the top bar and the toggle button.','rectangulum'); ?></label>
</td>
</tr>

<tr valign="top">
<th scope="row"><?php _e( 'Disable Comment Toggle', 'rectangulum' ); ?></th>
<td>
<input id="rectangulum_theme_settings[comment_toggle]" class="checkbox" type="checkbox" name="rectangulum_theme_settings[comment_toggle]" value="1" <?php checked( $options['comment_toggle'], 1 ); ?> />
<label class="description" for="rectangulum_theme_settings[comment_toggle]"><?php _e( 'Check the box if you wish to cancel an option to hide/show comments and toggle.','rectangulum'); ?></label>
</td>
</tr>

</table>

<p class="submit-changes">
<input type="submit" class="button-primary" value="<?php _e( 'Save Options', 'rectangulum' ); ?>" />
</p>
</form>
</div><!--//wrap -->

<!--END Page Options-->

<?php
}
/*=Sanitize------------------
-------------------------------*/
function rectangulum_options_validate( $input ) {

	$output = $options = get_option( 'rectangulum_theme_settings' );

		$output['file_avatar'] = wp_kses_post($input['file_avatar']);

		if( !isset( $input['topbar_disable'] ) ) {
		$input['topbar_disable'] = null;
			}
		$output['topbar_disable'] = ( $input['topbar_disable'] == 1 ? 1 : 0 );

		if( !isset( $input['comment_toggle'] ) ) {
		$input['comment_toggle'] = null;
			}
		$output['comment_toggle'] = ( $input['comment_toggle'] == 1 ? 1 : 0 );

	return apply_filters( 'rectangulum_options_validate', $output, $input, $options );
}
?>